<?php
if (!defined('SCHLIX_VERSION'))
    die('No Access');

global $CurrentUser, $Application;

$last_10_logs = \App\logViewer::getLastLog(10);
$log_count = count($last_10_logs);
$current_user_info = $CurrentUser->getCurrentUserInfo();

function renderBackendMenu($ul_class, $ul_id,  $ul_subtree_class_inner) {
    global $CurrentAdminAppName;

    $menu_items = \App\Admin::getAdminBackendMenuArray();
    $menu_str = '<ul class="' . $ul_class . '" id="' . $ul_id . '">';
    foreach ($menu_items as $m) {
        $submenus = '';
        $sub_has_active = false;
        $url = $m['url'] ? $m['url'] : \App\Admin::getAdminApp($m['app']);
        $active_class = $CurrentAdminAppName == $m['app'] ? ' class="active" ' : '';
        if ($m['submenus']) {
            $url = 'javascript:void(0)';
            $submenus = "<ul class=\"{$ul_subtree_class_inner}\" id=\"sub_{$m['app']}\">";

            foreach ($m['submenus'] as $sub) {
                $subli_class = [];
                if ($sub['type'] == 'divider') {
                    $submenus .= '<li class="menu-divider"><span></span></li>';
                } else {
                    $suburl = \App\Admin::getAdminApp($sub['app']);
                    $subicon = $sub['icon'] ? "<i class=\"fa {$sub['icon']}\"></i>" : '';
                    $subimg = $sub['image'] ? "<img src=\"{$sub['image']}\" />" : '';
                    if ($sub['image'])
                        $subli_class[] = 'app_list';
                    // also include sub-applications - May 28, 2017
                    if ($sub['app'] == $CurrentAdminAppName || str_starts_with($CurrentAdminAppName . '.', $sub['app'])) {
                        $subli_class[] = 'active';
                        $sub_has_active = true;
                    }
                    $subli_class_all = implode(' ', $subli_class);
                    $subli_class_str = $subli_class_all ? " class=\"{$subli_class_all}\"" : '';
                    
                    $submenus .= "<li id=\"menu_{$sub['app']}\"{$subli_class_str}><a href=\"{$suburl}\">{$subicon}{$subimg}&nbsp;{$sub['label']}</a></li>\n";
                }
            }
            $submenus .= '</ul>';
        }
        $root_li_class = [];
        if ($submenus)
            $root_li_class[] = 'treeview';  
        if ($m['app'] && (($CurrentAdminAppName == $m['app']) || $sub_has_active))
            $root_li_class[] = 'active';
        $rootli_class_all = implode(' ', $root_li_class);
        $rootli_class_str = $rootli_class_all ? " class=\"{$rootli_class_all}\"" : '';
        if ($m['icon']) {
            $extra_main_li_classz = '';
            $image_or_icon = "<i class=\"fa {$m['icon']}\"></i>";
        } else {
            $extra_main_li_classz = ' class="app_list" ';
            $image_or_icon = "<img src=\"{$m['image']}\" alt=\"{$m['app']}\" />";
        }
        if ($submenus)
        {
            $a_class_arr = ['menu-toggle'];
            if ($sub_has_active)
                $a_class_arr[] = 'toggled';
            $a_class_str = implode(' ', $a_class_arr);
            
            
            $a_href = "<a class=\"{$a_class_str}\" href=\"{$url}\">{$image_or_icon}&nbsp;{$m['label']}</a>";
        } else
        {
            $a_class = ' ';
            $a_href = "<a{$a_class}href=\"{$url}\">{$image_or_icon}&nbsp;{$m['label']}</a>";
        }
        
        $menu_str .= "<li {$extra_main_li_classz} id=\"menu_{$m['app']}\"{$rootli_class_str}>{$a_href}{$submenus}</li>\n";
    }
    $menu_str .= '</ul>';
    return $menu_str;
}
?>
<?php global $HTMLHeader ?>
<!doctype html>
<html>
    <head>
<?php include ('header.template.php') ?>
    </head>

    <body class="theme-grey">
        <!-- Page Loader -->
        <div class="page-loader-wrapper">
            <div class="loader">
                <div class="preloader">
                    <div class="spinner-layer pl-red">
                        <div class="circle-clipper left">
                            <div class="circle"></div>
                        </div>
                        <div class="circle-clipper right">
                            <div class="circle"></div>
                        </div>
                    </div>
                </div>
                <p>Please wait...</p>
            </div>
        </div>
        <!-- #END# Page Loader -->
        <!-- Overlay For Sidebars -->
        <div class="overlay"></div>
        <!-- #END# Overlay For Sidebars -->
        <!-- Top Bar -->
        <nav class="navbar" id="top_menu_bar">
            <div class="container-fluid">
                <div class="navbar-header">
                    <a href="javascript:void(0);" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#navbar-collapse-top" aria-expanded="false"></a>
                    <a href="javascript:void(0);" class="bars"></a>
                    <a href="<?= SCHLIX_SITE_HTTPBASE ?>/admin/" class="navbar-brand">
                        <!-- mini logo for sidebar mini 50x50 pixels -->
                        <img src="<?= TEMPLATE_PATH; ?>/images/my-company-logo.png" alt="SCHLIX CMS" title="Main" id="schlix-admin-logo" />
                    </a>

                </div>
                <div class="collapse navbar-collapse" id="navbar-collapse-top">
                    <ul class="nav navbar-nav navbar-right" id="right-menu-bar">
                        <!-- Notifications -->
                        <li class="dropdown">
                            <a href="javascript:void(0);" class="dropdown-toggle" data-toggle="dropdown" role="button">
                                <i class="material-icons">tv</i>
                                <span class="label-count"><?= $log_count ?></span>
                            </a>
                            <ul class="dropdown-menu">
                                <li class="header"><?= sprintf(___('Last %s log entries'), $log_count) ?></li>
                                <li class="body">
                                    <ul class="menu">
                                                <?php foreach ($last_10_logs as $log): ?>
                                        <li>
                                            <a href="javascript:void(0);">
                                               
                                                <div class="menu-info">
                                                    <p>
                                                    <?= SAFE_HTML($log['description']) ?></p>
                                                    <p>
                                                        <i class="fa fa-clock-o"></i> <?= time_since(strtotime($log['date_created'])) ?> <?= ___('ago') ?>
                                                    </p>
                                                </div>
                                            </a>
                                        </li>
                                            <?php endforeach; ?>    
                                    </ul>
                                </li>
                                <li class="footer">
                                    <a href="<?= \App\Admin::getAdminApp('logviewer') ?>"><?= ___('View all') ?></a>
                                </li>
                            </ul>
                        </li>
                        <!-- #END# Notifications --> 
                        <li class="pull-right"><a href="<?= SCHLIX_SITE_HTTPBASE . '/' . get_application_alias('admin') ?>/logout" class="js-right-sidebar" data-close="true"><i class="material-icons">power_settings_new</i></a></li>
                    </ul>
                </div>
            </div>
        </nav>
        <!-- #Top Bar -->
        <section>
            <!-- Left Sidebar -->
            <aside id="leftsidebar" class="sidebar">
                <!-- User Info -->
                <div class="row user-info">
                    <div class="col-xs-3 image">
                        <?php if ($current_user_info['avatar']): ?>
                            <?php
                            $avatar_small = $CurrentUser->getDataFileURLPath('avatar_small', $current_user_info['avatar']);
                            ?>
                                <img src="<?= $avatar_small ?>" id="User Avatar"  style="max-height:48px;border:none" />
                        <?php else: ?>
                            <i class="fa fa-user fa-3x"></i>
                        <?php endif ?>                    
                    </div>
                    <div class="col-xs-9">
                        <div class="name" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false"><?= SAFE_HTML($current_user_info['firstname'].' '.$current_user_info['lastname']) ?></div>
                        <div class="email"><?= SAFE_HTML($current_user_info['email_address']) ?></div>
                    </div>
                    <div class="col-xs-12">
                        <small><?= ___('Logged in') ?>&nbsp;<?= time_since($_SESSION['logged_in_since']) ?>&nbsp;<?= ___('ago') ?></small>
                    </div>
                </div>
                
                <!-- #User Info -->
                <!-- Menu -->
                <div class="sidebar-menu">
                    <?= \renderBackendMenu('list', 'top_admin_menu','ml-menu') ?>
                </div>
                <!-- #Menu -->
                <!-- Footer -->
                <div class="legal">
                    <div class="copyright">
                        <strong>Developed by <a href="https://www.schlix.com" target="_blank">My Company Name</a>.</strong>
                    </div>
                    <div class="version">
                        <strong>SCHLIX Engine: </strong> v<?= SCHLIX_VERSION ?>
                    </div>
                </div>
                <!-- #Footer -->
            </aside>
            <!-- #END# Left Sidebar -->
            <!-- Right Sidebar -->
            <!-- #END# Right Sidebar -->
        </section>

        <section class="schlix-content">
            <div class="container-fluid">
                <div class="block-header">
                    <h3 class="navbar-text" id="main-app-description"></h3>
                </div>
                <!-- Body Copy -->
                <div class="row clearfix">
                    <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
                        <div class="card">

                            <div class="body">
                                <!-- remove this text -->
                                <div class="alert alert-warning">
                                    <p><i class="fa fa-info-circle"></i> This is a theme for web development agencies and freelancers so you can put your own brand.</p>
                                    <p>Please change the theme name from "admincompanyname" and replace company name and logo to suit your needs and modify the CSS file as needed.</p>
                                    <p><i class="fa fa-exclamation-triangle"></i> You must keep the SCHLIX logo at the bottom of the login page and on the admin welcome page.</p>
                                    <p>To remove the warning, please edit <?= __FILE__ ?></p>
                                    <p>SCHLIX&trade; is a registered trademark of SCHLIX Web Inc.</p>
                                </div>
                                <!-- remove this text -->
                                <!-- ######################################### -->
                                <!-- ######################################### -->
                                <!-- ######################################### -->
                                <?= SCHLIX\cmsPageOutput::ApplicationBody(); ?>
                                <!-- ######################################### -->
                                <!-- ######################################### -->
                                <!-- ######################################### -->

                            </div>
                        </div>
                    </div>
                </div>  
                <!-- #END# Unordered List -->
            </div>
        </section>

    </body>

</html>